@@ -10,12 +10,11 @@
 #define __KCHATBASE_H__
 
 // own
-#include "libkdegamesprivate_export.h"
+#include "kdegamesprivate_export.h"
 // KF
 #include <KCompletion>
 // Qt
 #include <QFrame>
-#include <QLoggingCategory>
 // Std
 #include <memory>
 
@@ -27,9 +26,6 @@ class KChatBaseItemDelegate;
 class QModelIndex;
 class QPoint;
 
-Q_DECLARE_LOGGING_CATEGORY(GAMES_PRIVATE)
-Q_DECLARE_LOGGING_CATEGORY(GAMES_PRIVATE_KGAME)
-
 /**
  * \class KChatBase kchatbase.h <KChatBase>
  *
@@ -86,7 +82,9 @@ public:
      */
     ~KChatBase() override;
 
-    enum SendingIds { SendToAll = 0 };
+    enum SendingIds {
+        SendToAll = 0
+    };
 
     /**
      * @return The name that will be shown for messages from this widget. Either the
@@ -347,7 +345,7 @@ protected:
      * @param pos position to check index for
      * @return model index of message with coordinates pos
      */
-    const QModelIndex indexAt(const QPoint &pos) const;
+    QModelIndex indexAt(QPoint pos) const;
 
 private Q_SLOTS:
     /**
@@ -361,7 +359,7 @@ private Q_SLOTS:
      * Implements custom menu which is applicable for one chat message
      * @param pos point where custom menu has been requested (widget coordinates)
      */
-    virtual void customMenuHandler(const QPoint &pos);
+    virtual void customMenuHandler(QPoint pos);
 
 protected:
     KChatBase(KChatBasePrivate &dd, QWidget *parent, bool noComboBox);
